/* -*- Mode: Java; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 *
 * Copyright (c) 2001-2002  Fabricio Campos Zuardi.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

//default string with all supported sizes 
const defaultSizes = "468;60;234;60;120;60;336;280;338;282;728;105;728;90;500;62;184;90;160;600;160;60;150;70;140;800;120;800;120;600;0;0";
const defaultFlags = "1;1;1;0;0;0;0;0;0;0;0;0;0;0;0;0"; //default string with the on/off flags for all the sizes
const defaultVoid = true;  //defalut value for remove/hide
const defaultEnabled = true;

var bannerSizes;
var bannerFlags;
var bannerVoid;
var bannerEnabled;
var bannersizeArray;
var sizeenabled;

var bundle = document.getElementById("bannerblindbundle");

// function that modifies the UI based on the perferences
function loadConfig(){
  // getting the configuriation from mozilla preferences
  var pref;
  try {
    pref = Components.classes["@mozilla.org/preferences;1"].getService(Components.interfaces.nsIPref);
    bannerSizes = pref.GetCharPref("bannerblind.sizes");
    bannerFlags = pref.GetCharPref("bannerblind.flags");
  } catch (error) {
    bannerSizes = defaultSizes;
    bannerFlags = defaultFlags;
  }

  try {  bannerVoid = pref.GetBoolPref("bannerblind.void"); }
  catch(error) { bannerVoid = defaultVoid; }

  bannersizeArray = bannerSizes.split(";"); //array with all the supported bannersizes
  sizeenabled  = bannerFlags.split(";"); //array with the on/off table

  // remove last item (because of extra ';' character)
  if (bannersizeArray[bannersizeArray.length-1] == '')  bannersizeArray.pop();
  if (sizeenabled[sizeenabled.length-1] == '')          sizeenabled.pop();

  // check preference integrity
  if (bannersizeArray.length > (sizeenabled.length * 2)) {
    dump('ooops, something wrong with your Preference file. Reverting to default');
    bannerSizes = defaultSizes.split(";");
    bannerFlags = defaultFlags.split(";");
  } else
  if (bannersizeArray.length == (sizeenabled.length-1)*2) // fix ver1 RC1 and prior versions
    bannerEnabled = (sizeenabled.shift() == 1); // remove sizeenabled[0] and set it as bannerEnabled
  else {
    try { bannerEnabled = pref.GetBoolPref("bannerblind.enabled") }
    catch(error) { bannerEnabled = defaultEnabled }
  }

  // begining updating Preference controls
  document.getElementById("bannerblind-on").checked=bannerEnabled;

  for (var i=0; i<sizeenabled.length; i++) {
    addSize(bannersizeArray[i*2],bannersizeArray[i*2+1],(sizeenabled[i]==1)?"true":"false");
  }

  var voidon = document.getElementById("bannervoid-on");
  var voidoff = document.getElementById("bannervoid-off");
  voidon.setAttribute("oncommand", "bannerVoid=true");
  voidoff.setAttribute("oncommand","bannerVoid=false");

  if (bannerVoid) { voidon.setAttribute("selected","true"); } else { voidoff.setAttribute("selected","true"); }
}

function addSize(width,height,flag) {
  if ( (width==parseInt(width)) && (height==parseInt(height)) ) { //the sizes are numbers
    findItem = document.getElementById("li-"+width+"x"+height);
    if(findItem==undefined){ // check if this size already exists
      var lb = document.getElementById("sizes-list"); //the listbox that contains the sizes
      var listitemnode = document.createElement("listitem");
      var label = width+"x"+height;
      with (listitemnode) {
        setAttribute("id", "li-"+label);
        setAttribute("label", label);
        setAttribute("type", "checkbox");
        setAttribute("onclick","if (event.button==2) this.checked = !this.checked");
      }
      lb.appendChild(listitemnode);
      listitemnode.disabled = !(document.getElementById("bannerblind-on").checked);
      listitemnode.setAttribute("checked", flag);
    }else{
      alert(bundle.getString("e.dimAlreadyExists"));
      // findItem.selected = "true";
      findItem.focus();
    }
  } else {
    alert(bundle.getString("e.nonIntSizes"));
  }
}

function powerOnOff(){
  var state = !(document.getElementById("bannerblind-on").checked);
  var lb = document.getElementById("sizes-list"); //the listbox that contains the sizes
  for(var i=0; i<lb.childNodes.length;i++) { lb.childNodes[i].disabled = state };
}


function removeSizes(){
  var lb = document.getElementById("sizes-list"); //the listbox that contains the sizes
  var items=lb.selectedItems;
  if (items.length==0)
    alert(bundle.getString("e.noItemSelected"));
  else {
    // is selection list already sorted? -- tested, confirm yes ---

    //remove backwards because the selection array changes its length when you remove a listitem
    for (t=items.length-1;t>=0;t--) { lb.removeChild(items[t]); }
  }
}

function commitChanges(){
  var bannerSizes="";
  var bannerFlags="";
  var lb = document.getElementById("sizes-list");

  for (var i=0; i<lb.childNodes.length;i++){
    var label = lb.childNodes[i].getAttribute("label");
    if (label.length>2) {
      bannerSizes += label.substring(0,label.indexOf("x"))+";";
      bannerSizes += label.substring(label.indexOf("x")+1,label.length)+";";
      bannerFlags += (lb.childNodes[i].getAttribute("checked")=="true")?"1;":"0;";
    }
  }
  var pref = Components.classes["@mozilla.org/preferences;1"].getService(Components.interfaces.nsIPref);
  bannerEnabled = (document.getElementById("bannerblind-on").getAttribute("checked")=="true")

  pref.SetBoolPref("bannerblind.enabled", bannerEnabled);
  pref.SetCharPref("bannerblind.sizes",bannerSizes);
  pref.SetCharPref("bannerblind.flags",bannerFlags);
  pref.SetBoolPref("bannerblind.void", bannerVoid);
  closeWindow();
}

function restoreDefaults(){
  var pref = Components.classes["@mozilla.org/preferences;1"].getService(Components.interfaces.nsIPref);
  pref.SetCharPref("bannerblind.sizes",defaultSizes);
  pref.SetCharPref("bannerblind.flags",defaultFlags);
  pref.SetBoolPref("bannerblind.void", true);

  lb = document.getElementById("sizes-list");
  for (i=lb.childNodes.length-1;i>=0;i--) { lb.removeItemAt(i); }

  loadConfig();
//  closeWindow();
}

function closeWindow(){
  window.close();
}

function uninstall(){
  if (!confirm(bundle.getString("uninstall.confirm")))
     return false

  dump("BannerBlind: Uninstall\n");
//  include('chrome://jslib/content/jslib.js');
  include('chrome://jslib/content/install/uninstall.js');

  try {
    uninstall = new Uninstall('bannerblind');
    uninstall.uninstallPackage();
    alert(bundle.getString("uninstall.finish"));
    window.close();
  } catch(e) {
    alert('uninstallation failed. '+e);
  }
}

function checkNon() {
  lb = document.getElementById("sizes-list");
  for (i=lb.childNodes.length-1;i>=0;i--) {
    lb.childNodes[i].setAttribute("checked", "false")
  }
}


function checkInv() {
  lb = document.getElementById("sizes-list");
  for (i=lb.childNodes.length-1;i>=0;i--) {
    v = lb.childNodes[i].getAttribute("checked")=="true"?"false":"true";
    lb.childNodes[i].setAttribute("checked", v)
  }
}

function checkAll() {
  lb = document.getElementById("sizes-list");
  for (i=lb.childNodes.length-1;i>=0;i--) {
    lb.childNodes[i].setAttribute("checked", "true")
  }
}